{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
Today is {{ mydate|to_arrow|format_arrow('YYYY-MM-DD') }}
<img src="{{ url_for('invenio_formatter_badges.badge', title='DOI', value='invenio.12345', ext='svg') }}"></img>
Invenio will not be hacked! {{ content | safe | sanitize_html() }}.
